# -*- coding: utf-8 -*-


class Proto:
    ADD_ATTENTION = "add-attention"
    ADD_REVIEWER = "add-reviewer"
    DELETE_REVIEWER = "delete-reviewer"
    REMOVE_ATTENTION = "remove-attention"


class Separator:
    ACCOUNT = ","
    ACTION = ":"
    GROUP = " "
